#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Python Cursor on Target Module Utility Function Definitions."""

import re

__author__ = 'Greg Albrecht W2GMD <oss@undef.net>'
__copyright__ = 'Copyright 2020 Orion Labs, Inc.'
__license__ = 'Apache License, Version 2.0'


def cast(typ, value):
    if typ is None or value is None:
        return value
    return typ(value)


def parse_qos(qos):
    matches = re.search(
        r'(?<priority>\d)-(?<overtaking>\w)-(?<assurance>\w)', qos)
    return matches


def show_indent(outfile, level, pretty_print=True):
    if pretty_print:
        for _ in range(level):
            outfile.write('    ')



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Python Cursor on Target Module Function Definitions."""

import pycot

__author__ = 'Greg Albrecht <oss@undef.net>'
__copyright__ = 'Copyright 2020 Orion Labs, Inc.'
__license__ = 'Apache License, Version 2.0'


def parse_event_type(event_type: str) -> pycot.EventType:
    """Parses CoT Event Types from CoT Events."""
    if event_type.startswith('a'):
        return pycot.AtomEventType(event_type)
    elif event_type.startswith('b'):
        return pycot.DataEventType(event_type)
    elif event_type.startswith('c'):
        describes = 'Capability'
        raise pycot.UnsupportedEvent(f'Unsupported Event type: {describes}')
    elif event_type.startswith('r'):
        describes = 'Reservation'
        raise pycot.UnsupportedEvent(f'Unsupported Event type: {describes}')
    elif event_type.startswith('t'):
        describes = 'Tasking'
        raise pycot.UnsupportedEvent(f'Unsupported Event type: {describes}')
    else:
        raise pycot.UnsupportedEvent(f'Unknown Event Type: {event_type}')



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Python Cursor on Target Module Class Definitions."""

import gexml

__author__ = 'Greg Albrecht W2GMD <oss@undef.net>'
__copyright__ = 'Copyright 2020 Orion Labs, Inc.'
__license__ = 'Apache License, Version 2.0'


class Point(gexml.Model):
    """CoT Point"""
    class meta:  # NOQA pylint: disable=invalid-name,missing-class-docstring,too-few-public-methods
        tagname = 'point'
    lat = gexml.fields.Float()
    lon = gexml.fields.Float()
    hae = gexml.fields.Float()
    ce = gexml.fields.Float()
    le = gexml.fields.Float()


class UID(gexml.Model):
    """CoT UID"""
    class meta:  # NOQA pylint: disable=invalid-name,missing-class-docstring,too-few-public-methods
        tagname = 'uid'
    Droid = gexml.fields.String()


class Detail(gexml.Model):
    """CoT Detail"""
    class meta:  # NOQA pylint: disable=invalid-name,missing-class-docstring,too-few-public-methods
        tagname = 'detail'
    uid = gexml.fields.Model(UID, required=False)


class Event(gexml.Model):
    """CoT Event Object"""
    class meta:  # NOQA pylint: disable=invalid-name,missing-class-docstring,too-few-public-methods
        tagname = 'event'

    __str__ = gexml.Model.render

    version = gexml.fields.Float()
    event_type = gexml.fields.String(attrname='type')

    uid = gexml.fields.String()

    time = gexml.fields.DateTime()
    start = gexml.fields.DateTime(required=False)
    stale = gexml.fields.DateTime(required=False)
    point = gexml.fields.Model(Point, required=False)
    detail = gexml.fields.Model(Detail, required=False)
    access = gexml.fields.String(required=False)
    qos = gexml.fields.String(required=False)
    opex = gexml.fields.String(required=False)
    how = gexml.fields.String()


class EventType:  # pylint: disable=too-few-public-methods
    """CoT EventType"""

    describes = None
    type_fields = []

    def __init__(self, event_type=None):
        self.event_type = event_type
        split_event = event_type.split('-')
        data = dict(zip(self.type_fields[0:len(split_event)], split_event))
        for key, val in data.items():
            setattr(self, key, val)

    def __str__(self):
        return self.event_type


class AtomEventType(EventType):  # pylint: disable=too-few-public-methods
    """CoT AtomEventType
    a - atoms (anything you drop on your foot), based on MS2525B.
    """
    describes = 'Thing'
    type_fields = ['_describes', 'affiliation', 'battle_dimension', 'function']


class DataEventType(EventType):  # pylint: disable=too-few-public-methods
    """CoT DataEventType"""
    describes = 'Data'
    type_fields = ['_describes', 'dimension']



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Python Cursor on Target Module Exceptions."""

__author__ = 'Greg Albrecht <oss@undef.net>'
__copyright__ = 'Copyright 2020 Orion Labs, Inc.'
__license__ = 'Apache License, Version 2.0'


class UnsupportedEvent(Exception):
    """Unsupported CoT Event."""
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Setup for the Python Cursor on Target Module.

:author: Greg Albrecht W2GMD <oss@undef.net>
:copyright: Copyright 2020 Orion Labs, Inc.
:license: Apache License, Version 2.0
:source: <https://github.com/ampledata/pycot>
"""

import os
import setuptools
import sys

__title__ = 'pycot'
__version__ = '2.0.0'
__author__ = 'Greg Albrecht W2GMD <oss@undef.net>'
__copyright__ = 'Copyright 2020 Orion Labs, Inc.'
__license__ = 'Apache License, Version 2.0'


def publish():
    """Function for publishing package to pypi."""
    if sys.argv[-1] == 'publish':
        os.system('python setup.py sdist')
        os.system('twine upload dist/*')
        sys.exit()


publish()


setuptools.setup(
    name=__title__,
    version=__version__,
    description='Python Cursor on Target Module.',
    author='Greg Albrecht',
    author_email='oss@undef.net',
    packages=['pycot'],
    package_data={'': ['LICENSE']},
    package_dir={'pycot': 'pycot'},
    license=open('LICENSE').read(),
    long_description=open('README.rst').read(),
    url='https://github.com/ampledata/pycot',
    zip_safe=False,
    include_package_data=True,
    setup_requires=[
      'coverage >= 3.7.1',
      'httpretty >= 0.8.10',
      'nose >= 1.3.7'
    ],
    install_requires=[
        'gexml>=1.0.0'
    ],
    classifiers=[
        'Programming Language :: Python',
        'License :: OSI Approved :: Apache Software License'
    ],
    keywords=[
        'Cursor on Target'
    ]
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Python Cursor on Target Module.

"""
Python Cursor on Target Module.
~~~~


:author: Greg Albrecht W2GMD <oss@undef.net>
:copyright: Copyright 2020 Orion Labs, Inc.
:license: Apache License, Version 2.0
:source: <https://github.com/ampledata/pycot>

"""

from .constants import LOG_LEVEL, LOG_FORMAT  # NOQA

from .exceptions import UnsupportedEvent  # NOQA

from .classes import (Event, Point, Detail, UID, EventType,  # NOQA
                      AtomEventType, DataEventType)

from .functions import parse_event_type  # NOQA

__author__ = 'Greg Albrecht W2GMD <oss@undef.net>'
__copyright__ = 'Copyright 2020 Orion Labs, Inc.'
__license__ = 'Apache License, Version 2.0'
